@@ -3,6 +3,8 @@
 #include <qmobilityglobal.h>
 #include "myswipegesture.h"
 #include "explorer.h"
+#include "audiodevices.h"
+
 
 #include <QEvent>
 #include <QMouseEvent>
@@ -953,5 +955,7 @@ void hcMainWindow::on_pushButton_3_clicked()
 
 void hcMainWindow::on_pushButton_4_clicked()
 {
-
+    setWindowFlags(windowFlags() | Qt::Window);
+    AudioTest *myAudio = new AudioTest(this);
+    myAudio ->showFullScreen();
 }
