@@ -44,7 +44,7 @@ void pixelWindow::mouseMoveEvent( QMouseEvent *event)
 
 }
 
-void pixelWindow::paintEvent(QPaintEvent *event)
+void pixelWindow::paintEvent()
 {
 
   QPainter painter(this);
@@ -55,4 +55,5 @@ void pixelWindow::paintEvent(QPaintEvent *event)
     painter.drawEllipse (discposition.x()-10, discposition.y()-10,20, 20);
 
 
+
 }
